@@ -3,8 +3,9 @@ use warnings;
 
 package App::Map::Metro;
 
-our $VERSION = '0.0100'; # VERSION
 # ABSTRACT: Web interface to Map::Metro maps
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.0200';
 
 1;
 
@@ -18,9 +19,23 @@ __END__
 
 App::Map::Metro - Web interface to Map::Metro maps
 
+
+
+=begin html
+
+<p>
+<img src="https://img.shields.io/badge/perl-5.10+-blue.svg" alt="Requires Perl 5.10+" />
+<a href="https://travis-ci.org/Csson/p5-App-Map-Metro"><img src="https://api.travis-ci.org/Csson/p5-App-Map-Metro.svg?branch=master" alt="Travis status" /></a>
+<a href="http://cpants.cpanauthors.org/release/CSSON/App-Map-Metro-0.0200"><img src="http://badgedepot.code301.com/badge/kwalitee/CSSON/App-Map-Metro/0.0200" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=App-Map-Metro%200.0200"><img src="http://badgedepot.code301.com/badge/cpantesters/App-Map-Metro/0.0200" alt="CPAN Testers result" /></a>
+<img src="https://img.shields.io/badge/coverage-81.8%-orange.svg" alt="coverage 81.8%" />
+</p>
+
+=end html
+
 =head1 VERSION
 
-Version 0.0100, released 2015-01-24.
+Version 0.0200, released 2017-09-30.
 
 =head1 SYNOPSIS
 
@@ -52,17 +67,13 @@ L<Task::MapMetro::Maps>
 
 =back
 
-=head1 HOMEPAGE
-
-Please visit the project's homepage at L<https://metacpan.org/release/App-Map-Metro>.
-
 =head1 AUTHOR
 
 Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
